/*****************************/
/* File mixed.sas            */
/* Demonstrate mixed models. */
/*****************************/
OPTIONS LINESIZE=68;
TITLE 'Fake mixed data';

DATA fakeMixed;
  INFILE 'fakeMixed.txt' FIRSTOBS=2;
  INPUT SubjID ClassID male ses score;
  
RUN;

/* Create dataset with additional variable: centered ses */
PROC SQL;
    CREATE TABLE fakeMixed2 AS
      SELECT *, ses - mean(ses) as cses
      FROM fakeMixed;
QUIT;

PROC PRINT DATA=fakeMixed2(OBS=4);
RUN;

TITLE2 'Fixed effect model (just a grand mean)';
PROC MIXED DATA=fakeMixed2;
  MODEL score =  / SOLUTION;
RUN;

TITLE2 'Random intercept model REML)';
PROC MIXED DATA=fakeMixed2 COVTEST PLOTS=(ALL);
  CLASS ClassID;
  MODEL score = / SOLUTION;
  RANDOM INTERCEPT / SUBJECT=ClassID;
RUN;


TITLE2 'Random intercept model (ML)';
PROC MIXED DATA=fakeMixed2 COVTEST METHOD=ML PLOTS=(ALL);
  CLASS ClassID;
  MODEL score = / SOLUTION;
  RANDOM INTERCEPT / SUBJECT=ClassID;
RUN;


TITLE2 'Add centered ses';
PROC MIXED DATA=fakeMixed2 COVTEST NOCLPRINT METHOD=ML;
  CLASS ClassID;
  MODEL score = cses / SOLUTION;
  RANDOM INTERCEPT / SUBJECT=ClassID;
RUN;

TITLE2 'Add gender';
PROC MIXED DATA=fakeMixed2 COVTEST NOCLPRINT METHOD=ML;
  CLASS ClassID;
  MODEL score = cses male / SOLUTION;
  RANDOM INTERCEPT / SUBJECT=ClassID;
RUN;

TITLE2 'Random Intercept + fixed ses (REML)';
PROC MIXED DATA=fakeMixed2 COVTEST NOCLPRINT;
  CLASS ClassID;
  MODEL score = cses / SOLUTION;
  RANDOM INTERCEPT / SUBJECT=ClassID;
RUN;

TITLE2 'Add random slope';
PROC MIXED DATA=fakeMixed2 COVTEST NOCLPRINT;
  CLASS ClassID;
  MODEL score = cses / SOLUTION;
  RANDOM INTERCEPT cses / SUBJECT=ClassID TYPE=UN;
RUN;
