/******************************************/
/* File: nrs.sas                          */
/* Read name, rank and serial number data */
/******************************************/

/* Comments can be anything starting with slash-star and
   ending with star-slash. */

* Anything starting with a star and ending with a semicolon
  is also a comment (but this style is less preferred);

/* SAS commands end with a semicolon and can be written
   over multiple lines.  My convention is to use upper
   case for words that must match the example exactly
   and lower case for arbitrary names.
*/

/* SAS programs often start by setting some options that
   affect the entire program. Titles are useful! */    
OPTIONS LINESIZE=74;
TITLE 'Simple test of name, rank, serial number';

/* General rules: SAS names start with a letter, can be up to 
   32 characters, may include numbers and underscores, and are
   not case sensitive.  Commas are NOT used to separate list items.
   In data files, a period (.) is used to indicate missing data.
*/

/* The DATA step(s) name and read in data, i.e., to make it
   available for analysis.
   The INPUT command of a DATA step names the variables.  A dollar
   sign is needed to identify a string (non-numeric) variable.
   In this first example, column positions are used to specify
   where each variable is in the input file.  Normally, this is
   only used with fixed-column data files.
   Standard math plus special functions (see appendix) can be used
   to create new variables from old variables.
   Use "RUN;" to complete a DATA step or PROC step (see below).
   You can enter as many DATA steps as you like to have multiple
   datasets "open" at one time.
*/
    
DATA military;
    INFILE "nrs.dat";
    INPUT last $ 1-14 first $ 15-24 rank $ 25-35
        serialNum 36-42 IQ 46-48 bdate $ 51-60 sex 62;
    serIQrat = serialNum / IQ;
RUN;

/* PROC steps analyze data. */
/* They use the most recently used data set unless explicitly
   overridden with the optional data= option.
*/
    
PROC PRINT DATA=military;
RUN;

