/************************************/
/* File: readData.sas               */
/* LIBNAME and permanent data files */
/************************************/

/*****************************************************
INPUT statements read data and save the data to
SAS-format files, but without use of "libraries"
these files are "temporary" and automatically deleted
when you exit SAS.

Use "libraries" to make your SAS-format data files
"permanent", i.e., persistent from session to session.
If a file is permanent, then you don't need to repeat
the DATA and INPUT portions of your program the
next time you run SAS, you don't need to keep your
original data files around (though it is always good
practice to keep a copy), and the data will load
much faster.

Permanent SAS data files have an extension like
"sas7bdat".  Besides SAS, SPSS, the "foreign" package
of R, and several other programs can read these files.
*****************************************************/

OPTIONS LINESIZE=74;
    
/* A LIBNAME statement, used before the DATA or PROC
   steps, is used (as many times as needed) to attach
   a temporary (for one SAS session) SAS name to a
   folder or subdirectory where SAS data files are
   permanently stored.
        
   The first argument to LIBNAME is the name used to
   identify the library (subdirectory) for the current
   SAS session.  The second argument is a relative or
   absolute description of a subdirectory location, in
   quotes.  Note that you can use "." to store data in
   the current directory.

   In this example "mydata" is a subdirectory of the
   current directory.  By explicitly using
   "mylib.military" in the DATA statement, the "military"
   dataset is stored as a permanent file in the "mydata"
   folder.  Remember: the form "lib.name" refers to a 
   permanent data file, while the form "name" refers to a
   temporary one.

*/

LIBNAME mylib "mydata";

/* Read name, rank and serial number data using column positions */
DATA mylib.military;
    INFILE "nrs.dat";
    INPUT last $ 1-14 first $ 15-24 rank $ 25-35
        serialNum 36-42 IQ 46-48 bdate $ 51-60 sex 62;
    serIQrat = serialNum / IQ;
RUN;

/* Now you should end your SAS session, then come back
   and try the program dataRead2.sas.
*/

