/*******************************************/
/* File: readData2.sas                     */
/* DATA reading, continued.                */
/*******************************************/

/* Use an existing permanent SAS data file */
OPTIONS LINESIZE=74;
LIBNAME libForMe "mydata";
TITLE 'Read data examples';
PROC PRINT DATA=libForMe.military;
RUN;

/* printing only a few lines */
PROC PRINT DATA=libForMe.military(OBS=4);
RUN;


/* Input a data file that has a row of column headers. */
TITLE2 'With column headers';
DATA temp;
  INFILE "nrsH.dat" FIRSTOBS=2;
  /* Note that the SAS program can only skip, not use, the header. */
  INPUT last $ 1-14 first $ 15-24 rank $ 25-35
      serialNum 36-42 IQ 46-48 bdate $ 51-60 sex 62;
RUN;
PROC PRINT DATA=temp;
RUN;


/* Input a DATA file with spaces between the columns. */
TITLE2 'With spaces between columns';
DATA temp;
  INFILE "nrs.dat";
  INPUT last $ first $ rank $ serialNum IQ bdate $ sex;
RUN;
PROC PRINT DATA=temp;
RUN;


/* By default, the above chops strings off at 8 characters (and  */
/* does not treat dates as meaningful).                          */
/* INFORMATs solve both problems.                                */
TITLE2 'With informat for dates and wider last and rank';
DATA temp;
  INFILE "nrs.dat";
  INFORMAT last $9. first $8. rank $10. bdate MMDDYY10. ;
  *** Note: MMDDYY10 represents MM/DD/YYYY (10 bytes);
  INPUT last first rank serialNum IQ bdate sex;
  age = (today()-bdate)/365.25;
RUN;
PROC PRINT DATA=temp;
RUN;


/* Now we have a problem with dates not printing as desired. */
/* We specified the input format, but not the output format. */
/* Also numeric coded categorical variables can be better    */
/* shown if a PROC FORMAT is used to define VALUES for later */
/* use in FORMAT statements. (A final period (.) is needed   */
/* when referring back to these FORMATs.)                    */
TITLE2 'With formatted output';
PROC FORMAT;  /* optional LIBRARY= makes this permanent */
  VALUE sexfmt 1='Female' 2='Male';
RUN;
PROC PRINT DATA=temp;
  FORMAT bdate MMDDYY. sex sexfmt.;
  FORMAT age 5.1;
RUN;


/* Input a data file with commas between the columns (DSD). */
/* Sequential commas gives missing data (without the usual  */
/* "." missing value code.)  Quotes are removed from quoted */
/* strings.                                                 */
/* For any DATA step, FORMATs can be included, then they    */
/* are used for all subsequent PROCs.                       */
TITLE2 'Using DSD for commas';
DATA temp;
  INFILE "nrsC.dat" DSD;
  INFORMAT last $9. first $8. rank $10. bdate MMDDYY10. ;
  INPUT last $ first $ rank $ serialNum IQ bdate sex;
  FORMAT bdate MMDDYY. sex sexfmt.;
RUN;
PROC PRINT DATA=temp;
RUN;

/* Demonstrate conditionally dropping cases. */
TITLE2 'Dropping privates';
DATA temp;
  INFILE "nrs.dat";
  INFORMAT last $9. first $8. rank $10. bdate MMDDYY10. ;
  INPUT last first rank serialNum IQ bdate sex;
  IF rank="Private" THEN delete;
RUN;
PROC PRINT;
RUN;

/* Demonstrate conditionally altering variables. */
TITLE2 'IQgroup and funny created with if statements';
DATA temp;
  INFILE "nrs.dat";
  INFORMAT last $9. first $8. rank $10. bdate MMDDYY10. ;
  INPUT last first rank serialNum IQ bdate sex;
  IF IQ GE 100 THEN IQgroup = 'Normal';
    ELSE IQgroup='Dull';
  IF IQ GT 130 THEN IQgroup = 'Genius';  
  funny = 0;
  IF first = 'Jay' | last = 'Maher' THEN funny = 1;
RUN;
PROC PRINT;
RUN;





