/***************************/
/* File regTest.sas        */
/* Demonstrate regression. */
/***************************/
TITLE 'Algebra data analyzed as ANCOVA with GLM';
/* Note: DELIMITER='09'X designates tab separated data */
PROC FORMAT;
  VALUE schoolfmt 1="elem" 2="middle" 3="high";
RUN;
DATA algebra;
  INFILE 'algebra.txt' FIRSTOBS=2 DELIMITER='09'X;
  INPUT id$ school experience score;
  FORMAT school schoolfmt.;
RUN;
PROC PRINT DATA=algebra;
RUN;

/* Important note: WHERE can restrict cases for any PROC. */
/* The CLASS statement creates indicator variables automatically. */
/* A "*" can be used to create interaction variables. */
TITLE2 'ANCOVA with interaction';
PROC GLM DATA=algebra;
  WHERE experience<22;  * drop one outlier with experience=22;
  CLASS school;
  /* Solution is needed to get the coefficient table */
  MODEL score = school experience school*experience / SOLUTION;  
RUN;


TITLE2 'No interaction model; save and plot residuals';
PROC GLM DATA=algebra  PLOT=(ALL);  /* PLOT=(ALL) adds diagnostics */
  CLASS school;
  MODEL score = school experience / SOLUTION;  
  OUTPUT OUT=algdiag RESIDUAL=res PREDICTED=fit;
RUN;

/* Residual vs. fit plot */
PROC GPLOT DATA=algdiag;
  PLOT res*fit / VREF=0;
RUN;

/* Find sd of residuals for QN plot */
PROC MEANS DATA=algdiag;
  VAR res;
RUN;

/* QN plot */
PROC UNIVARIATE DATA=algdiag NOPRINT;
  VAR res;
  QQPLOT / NORMAL (MU=0 SIGMA=0.43253 COLOR=red);
RUN;

